import { LocalStorage } from 'quasar'

const state = {
  settings: {
    show12HourTimeFormat: false,
    showTasksInOnelist: false
  }
}

const mutations = {
  setShow12HourTimeFormat (state, value) {
    state.settings.show12HourTimeFormat = value
  },
  setShowTasksInOnelist (state, value) {
    state.settings.showTasksInOnelist = value
  },
  setSettings (state, value) {
    Object.assign(state.settings, value)
  }
}

const actions = {
  setShow12HourTimeFormat ({ commit, dispatch }, value) {
    commit('setShow12HourTimeFormat', value)
    dispatch('saveSettings')
  },
  setShowTasksInOnelist ({ commit, dispatch }, value) {
    commit('setShowTasksInOnelist', value)
    dispatch('saveSettings')
  },
  saveSettings ({ state }) {
    LocalStorage.set('settings', state.settings)
  },
  getSettings ({ commit }) {
    const settings = LocalStorage.getItem('settings')
    if (settings) {
      commit('setSettings', settings)
    }
  }
}

const getters = {
  settings: state => {
    return state.settings
  }
}

export default {
  namespaced: true,
  state,
  mutations,
  actions,
  getters
}
